@@ -98,7 +98,10 @@ import Prelude ()
 import Prelude.Compat
 
 import           Data.Aeson hiding
-  ((.:?), decode, decode', decodeStrict, decodeStrict'
+  ((.:?), (.:), decode, decode', decodeStrict, decodeStrict'
+#if MIN_VERSION_aeson (0,11,0)
+  , (.:!)
+#endif
 #if !MIN_VERSION_aeson (0,9,0)
   , eitherDecode, eitherDecode', eitherDecodeStrict, eitherDecodeStrict'
 #endif
@@ -107,6 +110,8 @@ import           Data.Aeson hiding
 #endif
   )
 
+import qualified Data.Aeson as Aeson
+
 import           Data.Aeson.Parser (value, value')
 
 #if !MIN_VERSION_aeson (0,9,0)
@@ -117,10 +122,10 @@ import qualified Data.Attoparsec.Lazy as L
 
 import           Control.Monad.Catch (MonadThrow (..), Exception)
 import           Data.Aeson.Types (Parser, modifyFailure, typeMismatch, defaultOptions)
-import           Data.ByteString as B
+import           Data.ByteString as BS
 import qualified Data.Scientific as Scientific
-import           Data.ByteString.Lazy as L
-import qualified Data.HashMap.Strict as H
+import           Data.ByteString.Lazy as LBS
+import qualified Data.HashMap.Strict as HM
 import           Data.Text as T
 import qualified Data.Text.Encoding as TE
 import           Data.Typeable (Typeable)
@@ -147,7 +152,7 @@ import Data.List.NonEmpty  (NonEmpty (..))
 import Data.Proxy          (Proxy (..))
 import Data.Tagged         (Tagged (..))
 
-import qualified Data.List.NonEmpty as NonEmpty
+import qualified Data.List.NonEmpty as NE
 import qualified Data.Vector        as V
 #endif
 
@@ -155,6 +160,11 @@ import qualified Data.Vector        as V
 import Data.Void (Void, absurd)
 #endif
 
+#if MIN_VERSION_aeson(2,0,0)
+import qualified Data.Aeson.Key as Key
+import qualified Data.Aeson.KeyMap as KM
+#endif
+
 import Data.Attoparsec.Number (Number (..))
 
 -- | Exception thrown by 'decode' - family of functions in this module.
@@ -170,21 +180,28 @@ eitherAesonExc (Right x)  = return x
 -- | Like original 'Data.Aeson.decode' but in arbitrary 'MonadThrow'.
 --
 -- Parse a top-level JSON value, i.e. also strings, numbers etc.
-decode :: (FromJSON a, MonadThrow m) => L.ByteString -> m a
+decode :: (FromJSON a, MonadThrow m) => LBS.ByteString -> m a
 decode = eitherAesonExc . eitherDecode
 
 -- | Like original 'Data.Aeson.decode'' but in arbitrary 'MonadThrow'.
-decode' :: (FromJSON a, MonadThrow m) => L.ByteString -> m a
+decode' :: (FromJSON a, MonadThrow m) => LBS.ByteString -> m a
 decode' = eitherAesonExc . eitherDecode'
 
 -- | Like original 'Data.Aeson.decodeStrict' but in arbitrary 'MonadThrow'.
-decodeStrict :: (FromJSON a, MonadThrow m) => B.ByteString -> m a
+decodeStrict :: (FromJSON a, MonadThrow m) => BS.ByteString -> m a
 decodeStrict = eitherAesonExc . eitherDecodeStrict
 
 -- | Like original 'Data.Aeson.decodeStrict'' but in arbitrary 'MonadThrow'.
-decodeStrict' :: (FromJSON a, MonadThrow m) => B.ByteString -> m a
+decodeStrict' :: (FromJSON a, MonadThrow m) => BS.ByteString -> m a
 decodeStrict' = eitherAesonExc . eitherDecodeStrict'
 
+(.:) :: (FromJSON a) => Object -> Text -> Parser a
+#if MIN_VERSION_aeson(2,0,0)
+obj .: key = obj Aeson..: Key.fromText key
+#else
+obj .: key = obj Aeson..: key
+#endif
+
 -- | Retrieve the value associated with the given key of an 'Object'.
 -- The result is 'Nothing' if the key is not present, or 'empty' if
 -- the value cannot be converted to the desired type.
@@ -195,7 +212,12 @@ decodeStrict' = eitherAesonExc . eitherDecodeStrict'
 --
 -- This operator is consistent in @aeson >=0.7 && <0.11@
 (.:?) :: (FromJSON a) => Object -> Text -> Parser (Maybe a)
-obj .:? key = case H.lookup key obj of
+obj .:? key =
+#if MIN_VERSION_aeson(2,0,0)
+  case KM.lookup (Key.fromText key) obj of
+#else
+  case HM.lookup key obj of
+#endif
                 Nothing -> pure Nothing
                 Just v  ->
 #if MIN_VERSION_aeson(0,10,0)
@@ -207,11 +229,21 @@ obj .:? key = case H.lookup key obj of
 #endif
 {-# INLINE (.:?) #-}
 
-#if !MIN_VERSION_aeson(0,11,0)
 -- | Like '.:?', but the resulting parser will fail,
 -- if the key is present but is 'Null'.
 (.:!) :: (FromJSON a) => Object -> Text -> Parser (Maybe a)
-obj .:! key = case H.lookup key obj of
+#if MIN_VERSION_aeson(2,0,0)
+obj .:! key = obj Aeson..:! Key.fromText key
+#else
+#if MIN_VERSION_aeson(0,11,0)
+(.:!) = (Aeson..:!)
+#else
+obj .:! key =
+#if MIN_VERSION_aeson(2,0,0)
+  case KM.lookup (Key.fromText key) obj of
+#else
+  case HM.lookup key obj of
+#endif
                 Nothing -> pure Nothing
                 Just v  ->
 #if MIN_VERSION_aeson(0,10,0)
@@ -223,6 +255,7 @@ obj .:! key = case H.lookup key obj of
 #endif
 {-# INLINE (.:!) #-}
 #endif
+#endif
 
 #if !MIN_VERSION_aeson(0,9,0)
 -- From Parser.Internal
@@ -238,26 +271,26 @@ jsonEOF' :: A.Parser Value
 jsonEOF' = value' <* A.skipSpace <* A.endOfInput
 
 -- | Like 'decode' but returns an error message when decoding fails.
-eitherDecode :: (FromJSON a) => L.ByteString -> Either String a
+eitherDecode :: (FromJSON a) => LBS.ByteString -> Either String a
 eitherDecode = eitherDecodeWith jsonEOF fromJSON
 {-# INLINE eitherDecode #-}
 
 -- | Like 'decodeStrict' but returns an error message when decoding fails.
-eitherDecodeStrict :: (FromJSON a) => B.ByteString -> Either String a
+eitherDecodeStrict :: (FromJSON a) => BS.ByteString -> Either String a
 eitherDecodeStrict = eitherDecodeStrictWith jsonEOF fromJSON
 {-# INLINE eitherDecodeStrict #-}
 
 -- | Like 'decode'' but returns an error message when decoding fails.
-eitherDecode' :: (FromJSON a) => L.ByteString -> Either String a
+eitherDecode' :: (FromJSON a) => LBS.ByteString -> Either String a
 eitherDecode' = eitherDecodeWith jsonEOF' fromJSON
 {-# INLINE eitherDecode' #-}
 
 -- | Like 'decodeStrict'' but returns an error message when decoding fails.
-eitherDecodeStrict' :: (FromJSON a) => B.ByteString -> Either String a
+eitherDecodeStrict' :: (FromJSON a) => BS.ByteString -> Either String a
 eitherDecodeStrict' = eitherDecodeStrictWith jsonEOF' fromJSON
 {-# INLINE eitherDecodeStrict' #-}
 
-eitherDecodeWith :: L.Parser Value -> (Value -> Result a) -> L.ByteString
+eitherDecodeWith :: L.Parser Value -> (Value -> Result a) -> LBS.ByteString
                  -> Either String a
 eitherDecodeWith p to s =
     case L.parse p s of
@@ -267,7 +300,7 @@ eitherDecodeWith p to s =
       L.Fail _ _ msg -> Left msg
 {-# INLINE eitherDecodeWith #-}
 
-eitherDecodeStrictWith :: A.Parser Value -> (Value -> Result a) -> B.ByteString
+eitherDecodeStrictWith :: A.Parser Value -> (Value -> Result a) -> BS.ByteString
                        -> Either String a
 eitherDecodeStrictWith p to s =
     case either Error to (A.parseOnly p s) of
@@ -356,7 +389,7 @@ instance FromJSON Version where
       where
         go [(v,[])] = return v
         go (_ : xs) = go xs
-        go _        = fail $ "could not parse Version"
+        go _        = fail "could not parse Version"
 
 instance ToJSON Ordering where
   toJSON     = toJSON     . orderingToText
@@ -418,11 +451,11 @@ instance FromJSON a => FromJSON (Const a b) where
     parseJSON = fmap Const . parseJSON
 
 instance (ToJSON a) => ToJSON (NonEmpty a) where
-    toJSON = toJSON . NonEmpty.toList
+    toJSON = toJSON . NE.toList
     {-# INLINE toJSON #-}
 
 #if MIN_VERSION_aeson(0,10,0)
-    toEncoding = toEncoding . NonEmpty.toList
+    toEncoding = toEncoding . NE.toList
     {-# INLINE toEncoding #-}
 #endif
 
@@ -472,7 +505,7 @@ scientificToNumber s
 -- | Decode a nested JSON-encoded string.
 withEmbeddedJSON :: String -> (Value -> Parser a) -> Value -> Parser a
 withEmbeddedJSON _ innerParser (String txt) =
-    either fail innerParser $ eitherDecode (L.fromStrict $ TE.encodeUtf8 txt)
+    either fail innerParser $ eitherDecode (LBS.fromStrict $ TE.encodeUtf8 txt)
 withEmbeddedJSON name _ v = typeMismatch name v
 {-# INLINE withEmbeddedJSON #-}
 #endif
